import { TargetLanguage } from "../TargetLanguage";
import { StringTypeMapping } from "../TypeBuilder";
import { Type, EnumType, ClassType } from "../Type";
import { RenderContext } from "../Renderer";
import { Option } from "../RendererOptions";
import { ConvenienceRenderer, ForbiddenWordsInfo } from "../ConvenienceRenderer";
import { Namer, Name, DependencyName } from "../Naming";
import { Declaration } from "../DeclarationIR";
import { Sourcelike, MultiWord } from "../Source";
export declare class PythonTargetLanguage extends TargetLanguage {
    protected getOptions(): Option<any>[];
    readonly stringTypeMapping: StringTypeMapping;
    readonly supportsUnionsWithBothNumberTypes: boolean;
    readonly supportsOptionalClassProperties: boolean;
    needsTransformerForType(t: Type): boolean;
    protected makeRenderer(renderContext: RenderContext, _untypedOptionValues: {
        [name: string]: any;
    }): PythonRenderer;
}
export declare class PythonRenderer extends ConvenienceRenderer {
    private readonly imports;
    private readonly declaredTypes;
    protected forbiddenNamesForGlobalNamespace(): string[];
    protected forbiddenForObjectProperties(_: ClassType, _classNamed: Name): ForbiddenWordsInfo;
    protected makeNamedTypeNamer(): Namer;
    protected namerForObjectProperty(): Namer;
    protected makeUnionMemberNamer(): null;
    protected makeEnumCaseNamer(): Namer;
    protected readonly commentLineStart: string;
    protected emitDescriptionBlock(lines: string[]): void;
    protected readonly needsTypeDeclarationBeforeUse: boolean;
    protected canBeForwardDeclared(t: Type): boolean;
    protected emitBlock(line: Sourcelike, f: () => void): void;
    protected withImport(module: string, name: string): Sourcelike;
    protected withTyping(name: string): Sourcelike;
    protected namedType(t: Type): Sourcelike;
    protected pythonType(t: Type): Sourcelike;
    protected declarationLine(t: Type): Sourcelike;
    protected declareType<T extends Type>(t: T, emitter: () => void): void;
    protected emitClassMembers(_t: ClassType): void;
    protected emitClass(t: ClassType): void;
    protected emitEnum(t: EnumType): void;
    protected emitDeclaration(decl: Declaration): void;
    protected emitImports(): void;
    protected emitDefaultLeadingComments(): void;
    protected emitSupportCode(): void;
    protected emitClosingCode(): void;
    protected emitSourceStructure(_givenOutputFilename: string): void;
}
export declare type ConverterFunction = "none" | "bool" | "int" | "from-float" | "to-float" | "str" | "to-enum" | "list" | "to-class" | "dict" | "union" | "from-datetime" | "to-datetime";
export declare class JSONPythonRenderer extends PythonRenderer {
    private readonly _deserializerFunctions;
    private readonly _converterNamer;
    private readonly _topLevelConverterNames;
    protected conv(cf: ConverterFunction): Sourcelike;
    protected convFn(cf: ConverterFunction): MultiWord;
    protected deserializerFn(t: Type): MultiWord;
    protected deserializer(value: Sourcelike, t: Type): Sourcelike;
    protected serializerFn(t: Type): MultiWord;
    protected serializer(value: Sourcelike, t: Type): Sourcelike;
    protected emitClassMembers(t: ClassType): void;
    protected emitSupportCode(): void;
    protected makeTopLevelDependencyNames(_t: Type, topLevelName: Name): DependencyName[];
    protected emitClosingCode(): void;
}
